# bundle.pl
#
# Script to handle some of the file management tasks for bundling
# Scheherazade for OS X and Windows.
#
# by David K. Elson
# 5/30/2008

use strict;

my $SCH_SRC = $ENV{SCHSRC} || ".";
my $SCH_DOCS = $ENV{SCHDOCS} || "docs/";
my $SCH_BUNDLE_DIR = $ENV{SCH_BUNDLEDIR} || die "Environment variable SCH_BUNDLEDIR must be set to the directory to which we should output our bundle.\n";
my $SCH_BUNDLE_NAME = $ENV{SCH_BUNDLENAME} || die "Environment variable SCH_BUNDLENAME must be set to the name for the bundled (archive) files.\n";
my $SCH_VERSION = $ENV{SCH_VERSION} || die "Environment variable SCH_VERSION must be set to the Scheherazade version.\n";
my $SCH_BUILD = $ENV{SCH_BUILD} || die "Environment variable SCH_BUILD must be set to the Scheherazade build (jar file).\n";

if (!(-d "$SCH_BUNDLE_DIR/OSX/$SCH_BUNDLE_NAME")) {
    die "Directory must exist: $SCH_BUNDLE_DIR/OSX/$SCH_BUNDLE_NAME";
}

if (!(-d "$SCH_BUNDLE_DIR/Windows/$SCH_BUNDLE_NAME")) {
    die "Directory must exist: $SCH_BUNDLE_DIR/OSX/$SCH_BUNDLE_NAME";
}

if (!(-d "$SCH_BUNDLE_DIR/Linux/$SCH_BUNDLE_NAME")) {
    die "Directory must exist: $SCH_BUNDLE_DIR/Linux/$SCH_BUNDLE_NAME";
}


my @README;

# Read in the README file
open (IN, "$SCH_SRC/bundleFiles/README.txt") || die "Can't open $SCH_SRC/dynamic/bundleFiles/README.txt: $!\n";

while (my $line = <IN>) {
    $line =~ s/\$\{VERSION\}/$SCH_VERSION/g;
    push (@README, $line);
}

close IN;



my @API_DEMO;

# Read in the API demo file.
open (IN, "$SCH_SRC/story/scheherazade/examples/ScheherazadeDemo.java") || die "Can't open $SCH_SRC/story/scheherazade/examples/ScheherazadeDemo.java: $!\n";

while (my $line = <IN>) {
    if ($line =~ /^package/) {
	next;
    }
    push (@API_DEMO, $line);
}

close IN;


####### LINUX ########

#Write the README file 
open (OUT, ">$SCH_BUNDLE_DIR/Linux/$SCH_BUNDLE_NAME/README.txt") || die "Can't open for writing $SCH_BUNDLE_DIR/Linux/$SCH_BUNDLE_NAME/README.txt: $!\n";
foreach my $line (@README) {
    print OUT $line;
}
close OUT;


# Write the API demo file
open (OUT, ">$SCH_BUNDLE_DIR/Linux/$SCH_BUNDLE_NAME/ScheherazadeDemo.java") || die "Can't open for writing $SCH_BUNDLE_DIR/Linux/$SCH_BUNDLE_NAME/ScheherazadeDemo: $!\n";
foreach my $line (@API_DEMO) {
    print OUT $line;
}
close OUT;


# Copy the jar file
system "cp $SCH_BUILD $SCH_BUNDLE_DIR/Linux/$SCH_BUNDLE_NAME";

# Copy the javadoc
system "mkdir $SCH_BUNDLE_DIR/Linux/$SCH_BUNDLE_NAME/docs";
`cd $SCH_DOCS; tar -cvf - . | (cd ../$SCH_BUNDLE_DIR/Linux/$SCH_BUNDLE_NAME/docs; tar -xvf -)`;

# Copy the utilities folder
system "mkdir $SCH_BUNDLE_DIR/Linux/$SCH_BUNDLE_NAME/utilities";
`cd $SCH_SRC/bundleFiles/utilities; tar -cvf - . | (cd ../../../$SCH_BUNDLE_DIR/Linux/$SCH_BUNDLE_NAME/utilities; tar -xvf -)`;

# Zip it up
system "cd $SCH_BUNDLE_DIR/Linux; tar -czvf $SCH_BUNDLE_NAME-Linux.tar.gz $SCH_BUNDLE_NAME; mv $SCH_BUNDLE_NAME-Linux.tar.gz ..";






####### OS X ########

#Write the README file 
open (OUT, ">$SCH_BUNDLE_DIR/OSX/$SCH_BUNDLE_NAME/README.txt") || die "Can't open for writing $SCH_BUNDLE_DIR/OSX/$SCH_BUNDLE_NAME/README.txt: $!\n";
foreach my $line (@README) {
    print OUT $line;
}
close OUT;


# Write the API demo file
open (OUT, ">$SCH_BUNDLE_DIR/OSX/$SCH_BUNDLE_NAME/ScheherazadeDemo.java") || die "Can't open for writing $SCH_BUNDLE_DIR/OSX/$SCH_BUNDLE_NAME/ScheherazadeDemo: $!\n";
foreach my $line (@API_DEMO) {
    print OUT $line;
}
close OUT;

# Copy the javadoc
system "mkdir $SCH_BUNDLE_DIR/OSX/$SCH_BUNDLE_NAME/docs";
`cd $SCH_DOCS; tar -cvf - . | (cd ../$SCH_BUNDLE_DIR/OSX/$SCH_BUNDLE_NAME/docs; tar -xvf -)`;

# Copy the utilities folder
system "mkdir $SCH_BUNDLE_DIR/OSX/$SCH_BUNDLE_NAME/utilities";
`cd $SCH_SRC/bundleFiles/utilities; tar -cvf - . | (cd ../../../$SCH_BUNDLE_DIR/OSX/$SCH_BUNDLE_NAME/utilities; tar -xvf -)`;

# Zip it up
system "cd $SCH_BUNDLE_DIR/OSX; tar -czvf $SCH_BUNDLE_NAME-OS_X.tar.gz $SCH_BUNDLE_NAME; mv $SCH_BUNDLE_NAME-OS_X.tar.gz ..";



####### WINDOWS #######

# Write the README file
# Convert OSX line breaks to Windows

open (OUT, ">$SCH_BUNDLE_DIR/Windows/$SCH_BUNDLE_NAME/README.txt") || die "Can't open for writing $SCH_BUNDLE_DIR/Windows/$SCH_BUNDLE_NAME/README.txt: $!\n";

foreach my $line (@README) {
    # Convert line breaks
    $line =~ s/\r\n|\n|\r/\r\n/g;
    print OUT $line;
}

close OUT;


# Write the API demo file
open (OUT, ">$SCH_BUNDLE_DIR/Windows/$SCH_BUNDLE_NAME/ScheherazadeDemo.java") || die "Can't open for writing $SCH_BUNDLE_DIR/Windows/$SCH_BUNDLE_NAME/ScheherazadeDemo: $!\n";
foreach my $line (@API_DEMO) {
    # Convert line breaks
    $line =~ s/\r\n|\n|\r/\r\n/g;
    print OUT $line;
}
close OUT;


# Read in the .BAT launcher
open (IN, "$SCH_SRC/bundleFiles/launchSchWindows.bat") || die "Can't open $SCH_SRC/bundleFiles/launchSchWindows.bat: $!\n";

my @LaunchBAT;

while (my $line = <IN>) {
    push (@LaunchBAT, $line);
}

close IN;

# Write the 32 bit BAT launcher to the build
open (OUT, ">$SCH_BUNDLE_DIR/Windows/$SCH_BUNDLE_NAME/$SCH_BUNDLE_NAME.BAT") || die "Can't open for writing $SCH_BUNDLE_DIR/Windows/$SCH_BUNDLE_NAME/$SCH_BUNDLE_NAME: $!\n";

foreach my $line (@LaunchBAT) {

    # Substitute the bundle name
    $line =~ s/\$\{BUNDLE\}/$SCH_BUNDLE_NAME/;

    # Convert line breaks
    $line =~ s/\r\n|\n|\r/\r\n/g;

    print OUT $line;
}

close OUT;

# Write the 64 bit BAT launcher to the build
open (OUT, ">$SCH_BUNDLE_DIR/Windows/$SCH_BUNDLE_NAME/$SCH_BUNDLE_NAME-64bit.BAT") || die "Can't open for writing $SCH_BUNDLE_DIR/Windows/$SCH_BUNDLE_NAME/$SCH_BUNDLE_NAME-64bit: $!\n";

foreach my $line (@LaunchBAT) {

    # Substitute the bundle name
    $line =~ s/\$\{BUNDLE\}/$SCH_BUNDLE_NAME/;

    # Convert line breaks
    $line =~ s/\r\n|\n|\r/\r\n/g;

    # Change the win32 directory to the win64 directory
    $line =~ s/system32/SysWOW64/;

    print OUT $line;
}

close OUT;


# Copy the javadoc
system "mkdir $SCH_BUNDLE_DIR/Windows/$SCH_BUNDLE_NAME/docs";
`cd $SCH_DOCS; tar -cvf - . | (cd ../$SCH_BUNDLE_DIR/Windows/$SCH_BUNDLE_NAME/docs; tar -xvf -)`;


# Copy the jar file
system "cp $SCH_BUILD $SCH_BUNDLE_DIR/Windows/$SCH_BUNDLE_NAME";


# Copy the utilities folder
system "mkdir $SCH_BUNDLE_DIR/Windows/$SCH_BUNDLE_NAME/utilities";
`cd $SCH_SRC/bundleFiles/utilities; tar -cvf - . | (cd ../../../$SCH_BUNDLE_DIR/Windows/$SCH_BUNDLE_NAME/utilities; tar -xvf -)`;

# Zip it up
system "cd $SCH_BUNDLE_DIR/Windows; zip -r $SCH_BUNDLE_NAME-Windows.zip $SCH_BUNDLE_NAME; mv $SCH_BUNDLE_NAME-Windows.zip ..";


